@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2019 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2020 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU Lesser General Public License Version 2.1
  *
@@ -26,8 +26,11 @@
 extern "C" {
 #endif
 
+#include <as-version.h>
+#include <as-context.h>
 #include <as-component.h>
 #include <as-enums.h>
+#include <as-enum-types.h>
 #include <as-provided.h>
 #include <as-metadata.h>
 #include <as-pool.h>
@@ -47,11 +50,13 @@ extern "C" {
 #include <as-launchable.h>
 #include <as-relation.h>
 #include <as-issue.h>
+#include <as-review.h>
 
 #include <as-validator.h>
 #include <as-validator-issue.h>
 
 #include <as-utils.h>
+#include <as-vercmp.h>
 #include <as-spdx.h>
 
 #ifdef __cplusplus
